import axios from '@/utils/axios'

/**
 * 获取所有部门
 * @returns Promise
 */
export function fetchAllTree() {
  return axios.post('/sys/dept/fetch/all')
}
/**
 * 获取所有部门包含用户
 * @returns Promise
 */
export function fetchUserTree() {
  return axios.post('/sys/dept/fetch/user')
}

/**
 * 通过部门id获取用户ids
 *
 * @param deptId 部门id
 * @return 用户ids
 * @date 2022.12.12
 */
export function userIdsByDeptId(deptId: string) {
  return axios.post(`/sys/dept/user/ids/by/${deptId}`)
}

/**
 * 重新设置部门成员
 * @param deptId 部门id
 * @param userIds 新成员ids
 */
export function resetDeptUser(deptId: string, userIds: string[]) {
  return axios.post('/sys/dept/reset/dept/user', { id: deptId, userIds })
}

/**
 * 移除部门中某个成员
 * @param deptId 部门id
 * @param userId 成员id
 */
export function removeDeptUser(deptId: string, userId: string) {
  return axios.post('/sys/dept/remove/dept/user', { deptId, userId })
}
